@@ -8,8 +8,6 @@ use Scalar::Util qw(blessed);
 
 test 'zone tests' => sub {
 
-    diag Test::Zone;
-
     my $self = shift;
 
     my ( $rset, %countries, %states, %zones, $data, $result );
@@ -100,7 +98,7 @@ test 'zone tests' => sub {
 
     cmp_ok( $result->country_count, '==', 0, "0 country in zone" );
 
-    $rset = $self->schema->resultset('ZoneCountry')
+    $rset = $self->ic6s_schema->resultset('ZoneCountry')
       ->search( { zones_id => $result->zones_id } );
     cmp_ok( $rset->count, '==', 0, "check cascade delete in ZoneCountry" );
 
